#[derive(BitFlagSet)]
{
// Attributes available to this derive:
#[bitflagset]
}
Derive alternative to the enum form of [bitflagset::bitflagset!].
Useful for tools like cbindgen that cannot expand macro_rules! invocations.
The struct must be a tuple struct with a single primitive field.
ⓘ
#[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, BitFlagSet)]
#[bitflagset(element = Color)]
struct ColorSet(u8);